==> filemv0.53.00.zip: source/file.cpp <==
#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <fstream.h>
#include <windows.h>
#include <commdlg.h>
#include "resource.h"
#include "file.h"
#include "Mes.h"
#include "initial.h"

//hFile
OPENFILENAME ofn;
#define ExtLen 6




//-----------------------------------------------------------------------
//	

void PopFileInitialize (HWND hwnd)
{
     static TCHAR szFilter[] = TEXT (" (*.tfa)\0*.tfa\0") \
                               TEXT ("All Files (*.*)\0*.*\0\0") ;
     
     ofn.lStructSize       = sizeof (OPENFILENAME) ;
     ofn.hwndOwner         = hwnd ;
     ofn.hInstance         = NULL ;
     ofn.lpstrFilter       = szFilter ;
     ofn.lpstrCustomFilter = NULL ;
     ofn.nMaxCustFilter    = 0 ;
     ofn.nFilterIndex      = 0 ;
     ofn.lpstrFile         = NULL ;          // Set in Open and Close functions
     ofn.nMaxFile          = MAX_PATH ;
     ofn.lpstrFileTitle    = NULL ;          // Set in Open and Close functions
     ofn.nMaxFileTitle     = MAX_PATH ;
     ofn.lpstrInitialDir   = NULL ;
     ofn.lpstrTitle        = NULL ;
     ofn.Flags             = 0 ;             // Set in Open and Close functions
     ofn.nFileOffset       = 0 ;
     ofn.nFileExtension    = 0 ;
     ofn.lpstrDefExt       = TEXT ("tfa") ;
     ofn.lCustData         = 0L ;
     ofn.lpfnHook          = NULL ;
     ofn.lpTemplateName    = NULL ;
}

void setOpenFileExtTs1()
{
     static TCHAR szFilterTs1[] = TEXT ("ts1 Files (*.ts1)\0*.ts1\0") \
                               TEXT ("All Files (*.*)\0*.*\0\0") ;
     ofn.lpstrFilter       = szFilterTs1 ;
     strcpy("ts1",ofn.lpstrDefExt );
}

//-----------------------------------------------------------------------
//	

BOOL PopFileOpenDlg (HWND hwnd, PTSTR pstrFileName, PTSTR pstrTitleName)
{
     ofn.hwndOwner         = hwnd ;
     ofn.lpstrFile         = pstrFileName ;
     ofn.lpstrFileTitle    = pstrTitleName ;
     ofn.Flags             = OFN_HIDEREADONLY | OFN_CREATEPROMPT ;
     
     return GetOpenFileName (&ofn) ;
}

//...................................
//	gqŐVt@C


void makenewfilename(char *filename,char *newfile,char *new_ad)
{
	char ext[ExtLen]="";
	char *pB;
	 wsprintf(newfile,"%s",filename);
	 pB=strrchr(newfile,'.');
	 if(pB!=NULL)
	 {
		 wsprintf(ext,"%s",pB+1);
		 wsprintf(pB,"%s.%s",new_ad,ext);
	 }
	 else wsprintf(newfile,"%s%s.%s",filename,new_ad,ext);
}

//...................................
//	gqŐVt@CAAԗp,max999


void makenewfilename(char *filename,char *newfile,DWORD num)
{
	char nm[ExtLen];
	wsprintf(nm,"_%03d",num);
	makenewfilename( filename, newfile, nm);
}

// łɂ邩`FbNAԃt@C쐬
// 1i߂
// numftHg͂O

void makenewfilenameEx(char *filename,char *newfile, DWORD num)
{
	while(1)
	{
		makenewfilename( filename, newfile, num);
		if( !exist(newfile) ) break;
		num++;
	}
}


//...................................
//	t@CA`FbN

BOOL checkfilename(char *filename,char *nextfile)
{
	char buff[MAX_PATH];
	ifstream in;
	char ext[ExtLen]="";
	ULONG num=0;
	char *pB;
	wsprintf(buff,filename);
	 pB=strrchr(buff,'_');
	 if(pB!=NULL) *pB='\0';
	 pB=strrchr(filename,'_');
	 if(pB!=NULL) 
	 {
		 pB++;
		 wsprintf(nextfile,pB);
		 pB=strrchr(nextfile,'.');
		 wsprintf(ext,pB+1);
		 *pB='\0';
		 sscanf(nextfile,"%d",&num);
		 wsprintf(nextfile,"%s_%03d.%s",buff,num+1,ext);
		 in.open(nextfile,ios::binary | ios::nocreate);
		 if(!in)
		 {
			 num=0;
			 wsprintf(nextfile,filename);
		 }

	 }
	 else 
	 {
		 pB=strrchr(filename,'\\');
		 if(pB!=NULL) pB++;
		 else pB=filename;
		 sscanf(pB,"%s",nextfile);
	 }

	 if(num>0) return TRUE;
	 else return FALSE;
}


//...................................
//	tH_ɐVt@C


void makenewfilename(char *filename,char *newfile,char *new_ad,char *ext)
{
	char *pB;
	 wsprintf(newfile,"%s",filename);
	 pB=strrchr(newfile,'.');
	 if(pB!=NULL)
	 {
		 wsprintf(pB,"%s.%s",new_ad,ext);
	 }
	 else wsprintf(newfile,"%s%s.%s",filename,new_ad,ext);
}

//NfBNg

void getini_ex(char*initial)
{
	char cdf[MAX_PATH],cddr[MAX_PATH],cddi[MAX_PATH];
	GetModuleFileName(NULL,cdf,MAX_PATH);
	_splitpath(cdf,cddr,cddi,NULL,NULL);
	wsprintf(initial,"%s\\%s",cddr,cddi);
}

//fBNg

void getpath(char*file,char *path)
{
	char cdf[MAX_PATH],cddr[MAX_PATH],cddi[MAX_PATH];
	_splitpath(file,cddr,cddi,NULL,NULL);
	wsprintf(path,"%s\\%s",cddr,cddi);
}

	
//JgfBNg

void getini_cu(char*initial,char*initialfile)
{
	char cd[MAX_PATH];
	GetCurrentDirectory(MAX_PATH,cd);
	wsprintf(initial,"%s\\%s",cd,initialfile);
}



HANDLE getHandle(char *file)
{
	return CreateFile(file,GENERIC_READ,FILE_SHARE_READ,NULL,
		OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
}


char *getExt(char *file)
{
	char *p =strrchr(file,'.');
	if( p++!=NULL) 
		if(p!=NULL)return p;
	return NULL;
}

DWORD getfilesize(char *name)
{
	//check length
	DWORD size=0;
	HANDLE f;
	f=getHandle(name);
	if(f!=NULL) 
	{
		size=max(GetFileSize(f,NULL),0);
		CloseHandle(f);
	}
	return size;
}


BOOL checkExt(char *name,char *ext)
{
	BOOL f=FALSE;
	char *p;
	if(name ==NULL) return FALSE;
	if(ext ==NULL) return FALSE;
	if(strlen(name)==0 ) return FALSE;
	if(strlen(ext)==0 ) return FALSE;
	p=strrchr(name,'.');
	if(p!=NULL)
	{
		p++;
		if(p==NULL) goto end;
		if(strlen(p)==0)goto end;
		if(strlen(p)!=strlen(ext)) ;
		else//toupper
		{
			//Mes(ext);
			for( int i=0;i<strlen(p);i++)
				if(toupper(p[i])!=toupper(ext[i])) goto end;
			f=TRUE;
		}
	}
end:
	return f;
}


BOOL checkExts(char *name,char *exts)
{
	char ext[ExtsLen];
	char *p=exts;
	if(p==NULL || name==NULL) return FALSE;
	if(strchr(p,';')==NULL) return checkExt(name,exts);
	BOOL ans =FALSE;
	while(p!=NULL)
	{
		if(strlen(p)<=1) break;
		strcpy(ext, p);
		if(strchr(ext,';')==NULL) return checkExt(name,ext);
		*strchr(ext,';')=0;
		if(strlen(ext)==0) break;
		if(checkExt(name,ext)) return TRUE;
		p +=strlen(ext);
		if(strlen(p)<=1) break;
		p++;
	}
	return FALSE;
}



#define MAX_PATH 1000
#define LEN 1024*512 //
unsigned long maxi=2147483648-1;

int cutcopy(char *fr, char *to, DWORD from, DWORD len)
{
	char b;
	char buf[LEN];
	unsigned long i,num;
	DWORD maxi;
	
	ifstream in(fr,ios::binary|ios::nocreate);
	if(!in) {return 0;}
	
	ofstream ou(to,ios::binary);
	if(!ou)  {return 0;}
	
	in.seekg(from,ios::beg);
	if(!in) {return 0;}

	if(len>0 || len>LEN) maxi=len;
	
	i=0;
	num=0;
	while(1)
	{
		memset(buf,0,LEN);
		in.read(buf,LEN);
		num =in.gcount();
		if(num==0) break;
		if(maxi >= LEN) 
		{
			ou.write(buf,num);
			maxi-=num;
			i+=num;
		}
		else 
		{
			ou.write(buf,min(num,maxi));
			i+=min(num,maxi);
			break;
		}
		//setstatusnum(i);
	}
}



// t@CXg ǂݍݖ{ 
//  IR[h _END, _FILE, _FOLDER

int getnextfile(char *dir, char *filter, char *file,int reset)
{
    char szfname[MAX_PATH + 5],szfnameback[MAX_PATH + 5];
    WIN32_FIND_DATA wfd;
    static HANDLE hFind;

    static int ans = 0;
    SYSTEMTIME localtm;
    FILETIME localft;
    char szBuf[MAX_PATH];
	BOOL rootflag=FALSE;

	if(reset==_closeOnly) 
	{
		ans =0;
		if( hFind !=NULL) FindClose(hFind);
		return _END;
	}
	if(strlen(dir)<4) rootflag=TRUE;//[g`FbN@蔲
	SetCurrentDirectory(dir);

	if(reset==0) ans =0;
	if(ans ==0)
	{
		hFind = FindFirstFile(filter, &wfd);
		if (hFind == INVALID_HANDLE_VALUE) {
			FindClose(hFind);
			return _END;
		} 
		else {
			strcpy(szfname, wfd.cFileName);
			strcpy(file, wfd.cFileName);
			if (wfd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) 
			{
				ans =_FOLDER;
			}
			else 
			{
				ans =_FILE;
			}
			return ans;
		}
    }

    if (FindNextFile(hFind, &wfd)) {
		strcpy(szfname, wfd.cFileName);
		strcpy(file, wfd.cFileName);
		if (wfd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) 
		{
			ans =_FOLDER;
		}
		else 
		{
			ans =_FILE;
		}
		return ans;
	}
    else 
	{
		FindClose(hFind);
		return _END;
	}
    return ans;
}


ofstream GetStream(char *file, char *path, ofstream &ou,int st)
{
	char dir[MAX_PATH];
	GetCurrentDirectory(MAX_PATH,dir);
	SetCurrentDirectory( path);
	ou.open( file ,st );
	SetCurrentDirectory( dir);
	return ou;
}

char *GetFullName(char *full, char *file, char *path, DWORD len)
{
	char dir[MAX_PATH];
	GetCurrentDirectory(MAX_PATH,dir);
	SetCurrentDirectory( path);
	_fullpath( full,file, len);
	SetCurrentDirectory( dir);
	return full;
}

char *quote( char *file)
{
	char buff[1000];
	char *p=buff;
	char *f=file;
	strcpy(p,file);
	*f++ ='\"';
	while(*p!=0) {*f++ = *p++; }
	*f++ ='\"';
	*f='\0';

	return file;
}


// t@C݂邩

BOOL exist(char *file)
{
	ifstream in(file ,ios::nocreate);
	if(!in) return FALSE;
	return TRUE;
}

==> filemv0.372.0.2.zip: source/file.cpp <==
#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <fstream.h>
#include <windows.h>
#include <commdlg.h>
#include "resource.h"
#include "file.h"

//hFile
OPENFILENAME ofn;
#define ExtLen 6




//-----------------------------------------------------------------------
//	

void PopFileInitialize (HWND hwnd)
{
     static TCHAR szFilter[] = TEXT (" (*.tfa)\0*.tfa\0") \
                               TEXT ("All Files (*.*)\0*.*\0\0") ;
     
     ofn.lStructSize       = sizeof (OPENFILENAME) ;
     ofn.hwndOwner         = hwnd ;
     ofn.hInstance         = NULL ;
     ofn.lpstrFilter       = szFilter ;
     ofn.lpstrCustomFilter = NULL ;
     ofn.nMaxCustFilter    = 0 ;
     ofn.nFilterIndex      = 0 ;
     ofn.lpstrFile         = NULL ;          // Set in Open and Close functions
     ofn.nMaxFile          = MAX_PATH ;
     ofn.lpstrFileTitle    = NULL ;          // Set in Open and Close functions
     ofn.nMaxFileTitle     = MAX_PATH ;
     ofn.lpstrInitialDir   = NULL ;
     ofn.lpstrTitle        = NULL ;
     ofn.Flags             = 0 ;             // Set in Open and Close functions
     ofn.nFileOffset       = 0 ;
     ofn.nFileExtension    = 0 ;
     ofn.lpstrDefExt       = TEXT ("tfa") ;
     ofn.lCustData         = 0L ;
     ofn.lpfnHook          = NULL ;
     ofn.lpTemplateName    = NULL ;
}

void setOpenFileExtTs1()
{
     static TCHAR szFilterTs1[] = TEXT ("ts1 Files (*.ts1)\0*.ts1\0") \
                               TEXT ("All Files (*.*)\0*.*\0\0") ;
     ofn.lpstrFilter       = szFilterTs1 ;
     strcpy("ts1",ofn.lpstrDefExt );
}

//-----------------------------------------------------------------------
//	

BOOL PopFileOpenDlg (HWND hwnd, PTSTR pstrFileName, PTSTR pstrTitleName)
{
     ofn.hwndOwner         = hwnd ;
     ofn.lpstrFile         = pstrFileName ;
     ofn.lpstrFileTitle    = pstrTitleName ;
     ofn.Flags             = OFN_HIDEREADONLY | OFN_CREATEPROMPT ;
     
     return GetOpenFileName (&ofn) ;
}

//...................................
//	gqŐVt@C


void makenewfilename(char *filename,char *newfile,char *new_ad)
{
	char ext[ExtLen]="";
	char *pB;
	 wsprintf(newfile,"%s",filename);
	 pB=strrchr(newfile,'.');
	 if(pB!=NULL)
	 {
		 wsprintf(ext,"%s",pB+1);
		 wsprintf(pB,"%s.%s",new_ad,ext);
	 }
	 else wsprintf(newfile,"%s%s.%s",filename,new_ad,ext);
}

//...................................
//	gqŐVt@CAAԗp,max999


void makenewfilename(char *filename,char *newfile,DWORD num)
{
	char nm[ExtLen];
	wsprintf(nm,"_%03d",num);
	makenewfilename( filename, newfile, nm);
}

// łɂ邩`FbNAԃt@C쐬
// 1i߂
// numftHg͂O

void makenewfilenameEx(char *filename,char *newfile, DWORD num)
{
	while(1)
	{
		makenewfilename( filename, newfile, num);
		if( !exist(newfile) ) break;
		num++;
	}
}


//...................................
//	t@CA`FbN

BOOL checkfilename(char *filename,char *nextfile)
{
	char buff[MAX_PATH];
	ifstream in;
	char ext[ExtLen]="";
	ULONG num=0;
	char *pB;
	wsprintf(buff,filename);
	 pB=strrchr(buff,'_');
	 if(pB!=NULL) *pB='\0';
	 pB=strrchr(filename,'_');
	 if(pB!=NULL) 
	 {
		 pB++;
		 wsprintf(nextfile,pB);
		 pB=strrchr(nextfile,'.');
		 wsprintf(ext,pB+1);
		 *pB='\0';
		 sscanf(nextfile,"%d",&num);
		 wsprintf(nextfile,"%s_%03d.%s",buff,num+1,ext);
		 in.open(nextfile,ios::binary | ios::nocreate);
		 if(!in)
		 {
			 num=0;
			 wsprintf(nextfile,filename);
		 }

	 }
	 else 
	 {
		 pB=strrchr(filename,'\\');
		 if(pB!=NULL) pB++;
		 else pB=filename;
		 sscanf(pB,"%s",nextfile);
	 }

	 if(num>0) return TRUE;
	 else return FALSE;
}


//...................................
//	tH_ɐVt@C


void makenewfilename(char *filename,char *newfile,char *new_ad,char *ext)
{
	char *pB;
	 wsprintf(newfile,"%s",filename);
	 pB=strrchr(newfile,'.');
	 if(pB!=NULL)
	 {
		 wsprintf(pB,"%s.%s",new_ad,ext);
	 }
	 else wsprintf(newfile,"%s%s.%s",filename,new_ad,ext);
}

//NfBNg

void getini_ex(char*initial)
{
	char cdf[MAX_PATH],cddr[MAX_PATH],cddi[MAX_PATH];
	GetModuleFileName(NULL,cdf,MAX_PATH);
	_splitpath(cdf,cddr,cddi,NULL,NULL);
	wsprintf(initial,"%s\\%s",cddr,cddi);
}

//fBNg

void getpath(char*file,char *path)
{
	char cdf[MAX_PATH],cddr[MAX_PATH],cddi[MAX_PATH];
	_splitpath(file,cddr,cddi,NULL,NULL);
	wsprintf(path,"%s\\%s",cddr,cddi);
}

	
//JgfBNg

void getini_cu(char*initial,char*initialfile)
{
	char cd[MAX_PATH];
	GetCurrentDirectory(MAX_PATH,cd);
	wsprintf(initial,"%s\\%s",cd,initialfile);
}




DWORD getfilesize(char *name)
{
	//check length
	DWORD size=0;
	HANDLE f;
	f=CreateFile(name,GENERIC_READ,FILE_SHARE_READ,NULL,
		OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
	if(f!=NULL) 
	{
		size=max(GetFileSize(f,NULL),0);
		CloseHandle(f);
	}
	return size;
}


BOOL checkExt(char *name,char *ext)
{
	BOOL f=FALSE;
	char *p;
	p=strrchr(name,'.');
	if(p!=NULL)
	{
		p++;
		if(p!=NULL)
		{
			if(strcmp(p,ext)==0) f=TRUE;
		}
	}
	return f;
}



#define MAX_PATH 1000
#define LEN 1024*512 //
unsigned long maxi=2147483648-1;

int cutcopy(char *fr, char *to, DWORD from, DWORD len)
{
	char b;
	char buf[LEN];
	unsigned long i,num;
	DWORD maxi;
	
	ifstream in(fr,ios::binary|ios::nocreate);
	if(!in) {return 0;}
	
	ofstream ou(to,ios::binary);
	if(!ou)  {return 0;}
	
	in.seekg(from,ios::beg);
	if(!in) {return 0;}

	if(len>0 || len>LEN) maxi=len;
	
	i=0;
	num=0;
	while(1)
	{
		memset(buf,0,LEN);
		in.read(buf,LEN);
		num =in.gcount();
		if(num==0) break;
		if(maxi >= LEN) 
		{
			ou.write(buf,num);
			maxi-=num;
			i+=num;
		}
		else 
		{
			ou.write(buf,min(num,maxi));
			i+=min(num,maxi);
			break;
		}
		//setstatusnum(i);
	}
}



// t@CXg ǂݍݖ{ 
//  IR[h _END, _FILE, _FOLDER

int getnextfile(char *dir, char *filter, char *file,int reset)
{
    char szfname[MAX_PATH + 5],szfnameback[MAX_PATH + 5];
    WIN32_FIND_DATA wfd;
    static HANDLE hFind;

    static int ans = 0;
    SYSTEMTIME localtm;
    FILETIME localft;
    char szBuf[MAX_PATH];
	BOOL rootflag=FALSE;

	if(strlen(dir)<4) rootflag=TRUE;//[g`FbN@蔲
	SetCurrentDirectory(dir);

	if(reset==0) ans =0;
	if(ans ==0)
	{
		hFind = FindFirstFile(filter, &wfd);
		if (hFind == INVALID_HANDLE_VALUE) {
			FindClose(hFind);
			return _END;
		} 
		else {
			strcpy(szfname, wfd.cFileName);
			strcpy(file, wfd.cFileName);
			if (wfd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) 
			{
				ans =_FOLDER;
			}
			else 
			{
				ans =_FILE;
			}
			return ans;
		}
    }

    if (FindNextFile(hFind, &wfd)) {
		strcpy(szfname, wfd.cFileName);
		strcpy(file, wfd.cFileName);
		if (wfd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) 
		{
			ans =_FOLDER;
		}
		else 
		{
			ans =_FILE;
		}
		return ans;
	}
    else 
	{
		FindClose(hFind);
		return _END;
	}
    return ans;
}


char *GetFullName(char *full, char *file, char *path, DWORD len)
{
	SetCurrentDirectory( path);
	_fullpath( full,file, len);
	return full;
}

char *quote( char *file)
{
	char buff[1000];
	char *p=buff;
	char *f=file;
	strcpy(p,file);
	*f++ ='\"';
	while(*p!=0) {*f++ = *p++; }
	*f++ ='\"';
	*f='\0';

	return file;
}


// t@C݂邩

BOOL exist(char *file)
{
	ifstream in(file ,ios::nocreate);
	if(!in) return FALSE;
	return TRUE;
}
